.. _nlp_tools:

===============================================
Nlp\_tools subpackage :mod:`melusine.nlp_tools`
===============================================

TODO : ADD DESCRIPTION OF THE SUBPACKAGE

------------------
List of submodules
------------------
.. contents::
   :local:


.. _tokenizer:

Tokenizer :mod:`melusine.nlp_tools.tokenizer`
---------------------------------------------

.. automodule:: melusine.nlp_tools.tokenizer
   :members:
   :undoc-members:
   :show-inheritance:


.. _phraser:

Phraser :mod:`melusine.nlp_tools.phraser`
-----------------------------------------

.. automodule:: melusine.nlp_tools.phraser
  :members:
  :undoc-members:
  :show-inheritance:


.. _embedding:

Embedding :mod:`melusine.nlp_tools.embedding`
---------------------------------------------

.. automodule:: melusine.nlp_tools.embedding
  :members:
  :undoc-members:
  :show-inheritance:
